@@ -754,7 +754,7 @@ def create_censor_file(input_dset,out_prefix=None,fraction=0.1,clip_to=0.1,max_e
     '''
     polort = auto_polort(input_dset)
     info = dset_info(input_dset)
-    outcount = [float(x.split()[0]) for x in subprocess.check_output(['3dToutcount','-fraction','-automask','-polort',str(polort),str(input_dset)]).split('\n')]
+    outcount = [float(x) for x in subprocess.check_output(['3dToutcount','-fraction','-automask','-polort',str(polort),str(input_dset)]).split('\n') if len(x.strip())>0]
     binary_outcount = [x<fraction for x in outcount]
     perc_outliers = sum(binary_outcount)/float(info.reps)
     if max_exclude and perc_outliers > max_exclude:
